@@ -32,10 +32,10 @@
 #endif
 
 #define PIXMAN_VERSION_MAJOR 0
-#define PIXMAN_VERSION_MINOR 38
+#define PIXMAN_VERSION_MINOR 42
 #define PIXMAN_VERSION_MICRO 0
 
-#define PIXMAN_VERSION_STRING "0.38.0"
+#define PIXMAN_VERSION_STRING "0.42.0"
 
 #define PIXMAN_VERSION_ENCODE(major, minor, micro) (	\
 	  ((major) * 10000)				\
@@ -47,4 +47,8 @@
 	PIXMAN_VERSION_MINOR,			\
 	PIXMAN_VERSION_MICRO)
 
+#ifndef PIXMAN_API
+# define PIXMAN_API
+#endif
+
 #endif /* PIXMAN_VERSION_H__ */
